@@ -1,4 +1,4 @@
-from ..utils import get_bot_message
+from ..utils import EmbedFactory, MainMenu, get_bot_message
 
 from disnake import MessageInteraction, ButtonStyle
 from disnake.ui import View, Button, button
@@ -11,6 +11,8 @@ class ChangeView(View):
         self.ctx = ctx
         self.bot_message = get_bot_message(ctx)
 
+        self.add_item(MainMenu(ctx))
+
     async def interaction_check(self, interaction: MessageInteraction) -> bool:
         return (
             interaction.author == self.ctx.author
