@@ -2,10 +2,8 @@ import random
 import aiosqlite
 import os
 
-from attr import has
-
 from ..utils import EmbedFactory
-from datetime import date, datetime
+from datetime import datetime
 from dotenv import load_dotenv
 from disnake.ext.commands import (
     Cog, 
@@ -25,8 +23,6 @@ def get_database() -> str:
             os.mkdir('./db')
         except FileExistsError:
             pass
-
-        db = open('./db/database.db', 'w')
         database_path = './db/database.db'
 
     return database_path
@@ -69,43 +65,71 @@ class Debug(Cog, name='debug'):
             self.bot._launch_time = datetime.utcnow()
         if not hasattr(bot, '_get_uptime'):
             self.bot._get_uptime = self.get_uptime
+        if not hasattr(bot, '_close'):
+            self.bot._close = self._close
         
-    
-
-
     async def connect_database(self):
         database_path = get_database()
         try:
-            self.db = await aiosqlite.connect(database_path)
+            self.bot._db = await aiosqlite.connect(database_path)
         except aiosqlite.OperationalError:
             raise MissingDatabase(f"{database_path} isn't a valid database!")
         except Exception as e:
             print(e)
 
-        cursor = await self.db.cursor()  
-        try:
-            await cursor.execute("SELECT * from blacklist")
-        except aiosqlite.OperationalError:
-            await cursor.execute('''
-                CREATE TABLE "blacklist" (
-                    "snowflake_id"	INTEGER,
-                    "commands"	TEXT
-                );
-            ''') 
+        cursor = await self.bot._db.cursor()  
+        await cursor.execute('''
+            CREATE TABLE IF NOT EXISTS "blacklist" (
+                "guild_id"	INTEGER,
+                "channel_id" INTEGER,
+                "user_id"  INTEGER,
+                "commands"	TEXT
+            );
+        ''') 
+        await self.bot._db.commit()
+
+    async def _close(self) -> None:
+        await self.bot._db.close()
+        await self.bot.close()
 
     async def bot_check(self, ctx: Context) -> bool:
         if ctx.command.hidden:
             if await self.bot.is_owner(ctx.author):
                 return True
-            return False
         
-        # cursor = await self.db.cursor()
-        # await cursor.execute('Select * from users where snowflake_id = ?', (ctx.member.id))
+        cursor = await self.bot._db.cursor()
+        await cursor.execute('Select commands from blacklist where user_id=?', (ctx.author.id,))
+        result = [l.strip() for l in ''.join([r[0] for r in await cursor.fetchall()]).split(',')]
+        if result:
+            if '0' in result:
+                return False
+            if ctx.command.name in result:
+                return False
+
+        await cursor.execute('Select commands from blacklist where channel_id=?', (ctx.channel.id,))
+        result = [l.strip() for l in ''.join([r[0] for r in await cursor.fetchall()]).split(',')]
+        if result:
+            if '0' in result:
+                return False
+            if ctx.command.name in result:
+                return False
+
+        await cursor.execute('Select commands from blacklist where guild_id=?', (ctx.guild.id,))
+        result = [l.strip() for l in ''.join([r[0] for r in await cursor.fetchall()]).split(',')]
+        if result:
+            if '0' in result:
+                return False
+            if ctx.command.name in result:
+                return False
 
         return not self.bot._paused
 
 
-        #TODO: check for blacklist in db
+    @command()
+    async def t(self, ctx): print('.')
+
+    @command()
+    async def e(self, ctx): print('.')
 
     @command(hidden=True)
     async def debug(self, ctx):
@@ -137,6 +161,9 @@ class Debug(Cog, name='debug'):
         stats:
             => view bot stats (ping, uptime, etc)
 
+        info:
+            => view debugger info
+
         close:
             -> pause
                 => pause bot 
@@ -145,6 +172,7 @@ class Debug(Cog, name='debug'):
             -> close
                 => close bot [confirm]
 
+
         """ 
 
         from . import DebugView
@@ -199,14 +227,18 @@ class Debug(Cog, name='debug'):
     @Cog.listener('on_command_error')
     async def check_failure(self, ctx: Context, error: Exception):
         if isinstance(error, CheckFailure):
-            return
+            if self.bot._paused:
+                return
+            return await ctx.send(f"```yaml\nAn admin has blacklisted you/your channel/your guild from using this command```")
 
         print(error)
 
     @Cog.listener('on_slash_command_error')
     async def slash_check_failure(self, ctx: Context, error: Exception):
         if isinstance(error, CheckFailure):
-            return
+            if self.bot._paused:
+                return
+            return await ctx.send(f"An admin has blacklisted `you`/`your channel`/`your guild` from using this command")
 
         print(error)
 
