@@ -16,6 +16,8 @@ bot_statistics = """
 -> Prefix: {7}
 -> Number of extensions loaded: {8}
 """
+DESCRIPTION = """
+"""
 
 class DebugView(View):
     def __init__(self, ctx: Context):
@@ -41,6 +43,17 @@ class DebugView(View):
             -> 
         """
 
+        from . import EchoView
+
+        embed = EmbedFactory.static_embed(
+            self.ctx, 
+            "View messageable", 
+            path="echo"
+        )
+
+        await interaction.response.defer()
+        await self.bot_message.edit(embed=embed, view=EchoView(self.ctx))
+
     @button(label="Blacklist", style=ButtonStyle.green)
     async def blacklist_button(
         self, button: Button, interaction: MessageInteraction
@@ -49,11 +62,19 @@ class DebugView(View):
         buttons:
             -> user
             -> channel
-                => blacklist user/channel
+                => blacklist user/channel   
         """
-        ...
 
-        #TODO: append to db
+        from . import BlacklistView
+
+        embed = EmbedFactory.static_embed(
+            self.ctx, 
+            "Blacklist/Unblacklist", 
+            path="blacklist"
+        )
+
+        await interaction.response.defer()
+        await self.bot_message.edit(embed=embed, view=BlacklistView(self.ctx))
 
     @button(label="Leave guild", style=ButtonStyle.green)
     async def leave_guild_button(
@@ -172,6 +193,25 @@ class DebugView(View):
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed)
 
+    @button(label="Info", style=ButtonStyle.blurple)
+    async def info_button(
+        self, button: Button, interaction: MessageInteraction
+    ):  
+        """
+        buttons:
+            none
+        """
+
+        embed = EmbedFactory.static_embed(
+            self.ctx, 
+            "Information about disnake-debug", 
+            path="info",
+            description=DESCRIPTION
+        )
+
+        await interaction.response.defer()
+        await self.bot_message.edit(embed=embed)
+
     @button(label="Close", style=ButtonStyle.danger)
     async def close_button(
         self, button: Button, interaction: MessageInteraction
